summaryrefslogtreecommitdiff
path: root/sw/source/core/SwNumberTree
diff options
context:
space:
mode:
authorMichael T. Whiteley <mike@whiteley.org>2011-12-07 02:33:51 -0800
committerTor Lillqvist <tlillqvist@suse.com>2011-12-08 11:32:41 +0200
commitdcfd4beb213c551f6ef6ba379651bf303bd9017a (patch)
treea819f50716357c2a5561f6b9a09809cfc52d7dbf /sw/source/core/SwNumberTree
parentad2eb6c4ba3ca36e2302c721a106dac80d266325 (diff)
childs -> children
Diffstat (limited to 'sw/source/core/SwNumberTree')
-rw-r--r--sw/source/core/SwNumberTree/SwNumberTree.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/sw/source/core/SwNumberTree/SwNumberTree.cxx b/sw/source/core/SwNumberTree/SwNumberTree.cxx
index 4a7f5c1c5c03..2f20150a0078 100644
--- a/sw/source/core/SwNumberTree/SwNumberTree.cxx
+++ b/sw/source/core/SwNumberTree/SwNumberTree.cxx
@@ -457,7 +457,7 @@ void SwNumberTreeNode::AddChild( SwNumberTreeNode * pChild,
Algorithm:
Search first child A that is greater than pChild,
- A may be the end of childs.
+ A may be the end of children.
If nDepth > 0 then
{
if A is first child then
@@ -833,7 +833,7 @@ bool SwNumberTreeNode::IsFirst() const
// If node isn't the first child, it is the second child and the
// first child is a phanton. In this case check, if the first phantom
// child have only phanton childs
if ( bResult &&
this != *(GetParent()->mChildren.begin()) &&
!(*(GetParent()->mChildren.begin()))->HasOnlyPhantoms() )
@@ -833,7 +833,7 @@ bool SwNumberTreeNode::IsFirst() const
// If node isn't the first child, it is the second child and the
// first child is a phanton. In this case check, if the first phantom
- // child have only phanton childs
+ // child have only phanton children
if ( bResult &&
this != *(GetParent()->mChildren.begin()) &&